// Module: CalPNCoreData
// Author: Hassan Siddiqui
//
// Description: Cal PN Instrument-specific data/methods for arf generation.
// 
// Comments: 
//  
// Modifications: See ChangeLog
// 
// $Id: CalPNCoreData.cc,v 1.1.1.1 2004/02/09 14:54:12 eojero Exp $

/* General */

/* SAS-specific classes */
#include "Xmm.h"
#include "Tracer.h"

/* Local classes */
#include "CalPNCoreData.h"
#include "SimpleIterator.h"
#include "NonUnifBinnedAxis.h"
#include "NullPileupCorrector.h"

/* Constructors */

CalPNCoreData::CalPNCoreData( Xmm::Instrument instrumentID,
			      const string & datamode,
			      const string & dateobs,
			      const PosWCS * const poswcs,
			      const string & filter,
			      double psfenergy):
  CalCoreData(psfenergy, datamode, dateobs, poswcs)
{
  errstr << "Creating CalPNCoreData object .. "
         << filter
	 << Sas::message(Msg::App, Msg::Verbose);


  /* Set up CAL server */
  //calServer.setInstrument(Xmm::EPN);
  calServer.state()->ccd()->set(EPNcam::CCD_1);
  //  calServer.state()->node()->set(Xmm::PRIMARY_NODE);

 // calServer.state()->filter()->set(Xmm::toFilter(filter)); 

  /* Switch off randomization */
  //calServer.state()->randomize()->set(false);

  /* Initialise remaining members */
  init(instrumentID);
};

/*  Destructors  */
CalPNCoreData::~CalPNCoreData()
{
  PROC;
  ENDPROC;
};

unsigned CalPNCoreData::ccdFirst() const 
{ PROC; RETURN EPNcam::CCD_FIRST; }

unsigned CalPNCoreData::ccdLast()  const 
{ PROC; RETURN EPNcam::CCD_LAST;  } 


/** Iterator methods. */

GeneralIterator<int> * CalPNCoreData::xpixelIterator() const
{
  PROC;
  RETURN ( new SimpleIterator<int>( _ePNCam.minX(), 
				    _ePNCam.maxX()) );
}

GeneralIterator<int> * CalPNCoreData::ypixelIterator() const
{
  PROC;
  RETURN ( new SimpleIterator<int>( _ePNCam.minY(), 
				    _ePNCam.maxY()) );
}


